@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ctrlf" "1.6.1"
+(define-package "ctrlf" "20251212.141"
   "Emacs finally learns how to ctrl+F."
   '((emacs "25.1"))
   :url "https://github.com/radian-software/ctrlf"
-  :commit "452723c046c54f66f590900548d8eb4a7783e528"
-  :revdesc "452723c046c5"
+  :commit "3e1d4d74b201e45a2d471675f5fdae370f23f947"
+  :revdesc "3e1d4d74b201"
   :keywords '("extensions")
   :authors '(("Radian LLC" . "contact+ctrlf@radian.codes"))
   :maintainers '(("Radian LLC" . "contact+ctrlf@radian.codes")))
